import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_microsoft_login/auth_success.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:office365_login_flutter/office365_login_flutter.dart';
import 'package:shared_preferences/shared_preferences.dart';

class MS365Login extends StatefulWidget {
  const MS365Login({Key? key}) : super(key: key);
  @override
  State<MS365Login> createState() => _MS365LoginState();
}

class _MS365LoginState extends State<MS365Login> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        appBar: AppBar(
          title: const Text("Microsoft 365 Auth"),
        ),
        body: buildLoginContent()
    );
  }

  buildLoginContent() {
    return Center(
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          const Text(
            "Authentication",
            style: TextStyle(fontSize: 22),
          ),
          const SizedBox(
            height: 30,
          ),
          MaterialButton(
            onPressed: () async {
              String response = await ms365Login();
              if(response.isNotEmpty){
                Navigator.pushReplacement(
                    context,
                    MaterialPageRoute(
                        builder: (context) => AuthSuccessView(detail: "success")));
              }else{
                showToastMessage("authentication failed");
              }
            },
            color: Colors.blue,
            child: const Text(" Microsoft 365 Login ", style: TextStyle(fontSize: 20),),
          ),
          const SizedBox(
            height: 30,
          ),
        ],
      ),
    );
  }
}

Future<dynamic> ms365Login() async {
  try {
    final AuthorizationTokenResponse? result = await  const Office365Login().authentication(
      AuthorizationTokenRequest(
        'b4b47313-22b0-4993-b9b9-a4725372df9e',
        'msauth://com.example.flutter_microsoft_login/VzSiQcXRmi2kyjzcA%2BmYLEtbGVs%3D',
        discoveryUrl: 'https://login.microsoftonline.com/common/v2.0/.well-known/openid-configuration',
        scopes: ['openid','profile', 'email',],
        serviceConfiguration: const AuthorizationServiceConfiguration(
          authorizationEndpoint: 'https://login.microsoftonline.com/common/oauth2/v2.0/authorize',
          tokenEndpoint: 'https://login.microsoftonline.com/common/oauth2/v2.0/token',
        ),
      ),
    );

    if(result?.accessToken != null){
      final prefs = await SharedPreferences.getInstance();
      await prefs.setString('accessToken', "token");
      return result?.accessToken;
    }
    return "";

  } on PlatformException catch (e) {
    return "";
  }
}

void showToastMessage(String message) {
  Fluttertoast.showToast(
      msg: message,
      toastLength: Toast.LENGTH_LONG,
      gravity: ToastGravity.BOTTOM,
      textColor: Colors.white,
      fontSize: 16.0
  );
}
